@@ -4,6 +4,7 @@ import (
 	"reflect"
 	"testing"
 
+	"github.com/minamijoyo/tfmigrate-storage/local"
 	"github.com/minamijoyo/tfmigrate/history"
 )
 
@@ -27,7 +28,7 @@ tfmigrate {
 }
 `,
 			want: &history.Config{
-				Storage: &history.LocalStorageConfig{
+				Storage: &local.Config{
 					Path: "tmp/history.json",
 				},
 			},
