@@ -322,3 +322,20 @@ func MatchTerraformVersion(ctx context.Context, tf TerraformCLI, constraints str
 	}
 	return c.Check(v), nil
 }
+
+// IsPreleaseTerraformVersion returns true if terraform version is a prelease.
+func IsPreleaseTerraformVersion(ctx context.Context, tf TerraformCLI) (bool, error) {
+	tfVersionRaw, err := tf.Version(ctx)
+	if err != nil {
+		return false, fmt.Errorf("failed to get terraform version: %s", err)
+	}
+	v, err := version.NewVersion(tfVersionRaw)
+	if err != nil {
+		return false, fmt.Errorf("failed to parse terraform version: %s", err)
+	}
+
+	if v.Prerelease() != "" {
+		return true, nil
+	}
+	return false, nil
+}
